==> huaweicloudsdkdataartsstudio-3.1.68-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/update_factory_job_name_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateFactoryJobNameRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_name': 'str',
        'workspace': 'str',
        'authorization': 'str',
        'host': 'str',
        'body': 'UpdateFactoryJobNameRequestBody'
    }

    attribute_map = {
        'job_name': 'job_name',
        'workspace': 'workspace',
        'authorization': 'Authorization',
        'host': 'Host',
        'body': 'body'
    }

    def __init__(self, job_name=None, workspace=None, authorization=None, host=None, body=None):
        """UpdateFactoryJobNameRequest

        The model defined in huaweicloud sdk

        :param job_name: 作业名
        :type job_name: str
        :param workspace: 工作空间ID
        :type workspace: str
        :param authorization: 使用AK/SK进行认证时该字段必选
        :type authorization: str
        :param host: 使用AK/SK进行认证时该字段必选
        :type host: str
        :param body: Body of the UpdateFactoryJobNameRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateFactoryJobNameRequestBody`
        """
        
        

        self._job_name = None
        self._workspace = None
        self._authorization = None
        self._host = None
        self._body = None
        self.discriminator = None

        self.job_name = job_name
        self.workspace = workspace
        if authorization is not None:
            self.authorization = authorization
        if host is not None:
            self.host = host
        if body is not None:
            self.body = body

    @property
    def job_name(self):
        """Gets the job_name of this UpdateFactoryJobNameRequest.

        作业名

        :return: The job_name of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """Sets the job_name of this UpdateFactoryJobNameRequest.

        作业名

        :param job_name: The job_name of this UpdateFactoryJobNameRequest.
        :type job_name: str
        """
        self._job_name = job_name

    @property
    def workspace(self):
        """Gets the workspace of this UpdateFactoryJobNameRequest.

        工作空间ID

        :return: The workspace of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this UpdateFactoryJobNameRequest.

        工作空间ID

        :param workspace: The workspace of this UpdateFactoryJobNameRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def authorization(self):
        """Gets the authorization of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :return: The authorization of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        """Sets the authorization of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :param authorization: The authorization of this UpdateFactoryJobNameRequest.
        :type authorization: str
        """
        self._authorization = authorization

    @property
    def host(self):
        """Gets the host of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :return: The host of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :param host: The host of this UpdateFactoryJobNameRequest.
        :type host: str
        """
        self._host = host

    @property
    def body(self):
        """Gets the body of this UpdateFactoryJobNameRequest.

        :return: The body of this UpdateFactoryJobNameRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.UpdateFactoryJobNameRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this UpdateFactoryJobNameRequest.

        :param body: The body of this UpdateFactoryJobNameRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateFactoryJobNameRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateFactoryJobNameRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdataartsstudio-3.1.151-py2.py3-none-any.whl: huaweicloudsdkdataartsstudio/v1/model/update_factory_job_name_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpdateFactoryJobNameRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'job_name': 'str',
        'workspace': 'str',
        'authorization': 'str',
        'host': 'str',
        'body': 'UpdateFactoryJobNameRequestBody'
    }

    attribute_map = {
        'job_name': 'job_name',
        'workspace': 'workspace',
        'authorization': 'Authorization',
        'host': 'Host',
        'body': 'body'
    }

    def __init__(self, job_name=None, workspace=None, authorization=None, host=None, body=None):
        r"""UpdateFactoryJobNameRequest

        The model defined in huaweicloud sdk

        :param job_name: 作业名
        :type job_name: str
        :param workspace: 工作空间ID
        :type workspace: str
        :param authorization: 使用AK/SK进行认证时该字段必选
        :type authorization: str
        :param host: 使用AK/SK进行认证时该字段必选
        :type host: str
        :param body: Body of the UpdateFactoryJobNameRequest
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateFactoryJobNameRequestBody`
        """
        
        

        self._job_name = None
        self._workspace = None
        self._authorization = None
        self._host = None
        self._body = None
        self.discriminator = None

        self.job_name = job_name
        self.workspace = workspace
        if authorization is not None:
            self.authorization = authorization
        if host is not None:
            self.host = host
        if body is not None:
            self.body = body

    @property
    def job_name(self):
        r"""Gets the job_name of this UpdateFactoryJobNameRequest.

        作业名

        :return: The job_name of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        r"""Sets the job_name of this UpdateFactoryJobNameRequest.

        作业名

        :param job_name: The job_name of this UpdateFactoryJobNameRequest.
        :type job_name: str
        """
        self._job_name = job_name

    @property
    def workspace(self):
        r"""Gets the workspace of this UpdateFactoryJobNameRequest.

        工作空间ID

        :return: The workspace of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        r"""Sets the workspace of this UpdateFactoryJobNameRequest.

        工作空间ID

        :param workspace: The workspace of this UpdateFactoryJobNameRequest.
        :type workspace: str
        """
        self._workspace = workspace

    @property
    def authorization(self):
        r"""Gets the authorization of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :return: The authorization of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        r"""Sets the authorization of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :param authorization: The authorization of this UpdateFactoryJobNameRequest.
        :type authorization: str
        """
        self._authorization = authorization

    @property
    def host(self):
        r"""Gets the host of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :return: The host of this UpdateFactoryJobNameRequest.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        r"""Sets the host of this UpdateFactoryJobNameRequest.

        使用AK/SK进行认证时该字段必选

        :param host: The host of this UpdateFactoryJobNameRequest.
        :type host: str
        """
        self._host = host

    @property
    def body(self):
        r"""Gets the body of this UpdateFactoryJobNameRequest.

        :return: The body of this UpdateFactoryJobNameRequest.
        :rtype: :class:`huaweicloudsdkdataartsstudio.v1.UpdateFactoryJobNameRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this UpdateFactoryJobNameRequest.

        :param body: The body of this UpdateFactoryJobNameRequest.
        :type body: :class:`huaweicloudsdkdataartsstudio.v1.UpdateFactoryJobNameRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateFactoryJobNameRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
